@@ -18,11 +18,13 @@ load_provider_data = function(provider) {
     inherits(provider, "sfc_POINT") ||
     provider %!in% oe_available_providers()
   ) {
-    stop(
-      "You can only select one of the following providers: ",
-      paste(setdiff(oe_available_providers(), "test"), collapse = " - "),
-      ". Did you pass more than one place to oe_match or oe_get?",
-      call. = FALSE
+    oe_stop(
+      .subclass = "load_provider_data-InvalidProvider",
+      message = paste0(
+        "You can only select one of the following providers: ",
+        paste(setdiff(oe_available_providers(), "test"), collapse = " - "),
+        ". Did you pass more than one place to oe_match or oe_get?"
+      )
     )
   }
 
@@ -70,8 +72,9 @@ oe_providers = function(quiet = FALSE) {
 
   oe_message(
     "Check the corresponding help pages to read more details about the ",
-    "fields in each database (e.g. ?geofabrik_zones)",
-    quiet = quiet
+    "fields in each database (e.g. ?geofabrik_zones).",
+    quiet = quiet,
+    .subclass = "oe_providers_Info"
   )
 
   # Summary of results
